@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.002001'; # VERSION
+our $VERSION = '2.002002'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -56,7 +56,9 @@ around add_file => sub {
 
 	if ( $self->zilla->copyright_holder ) {
 		for ( split( ' ', $self->zilla->copyright_holder ) ) {
-			my ( $word ) = $_ =~ /(\w+)/xms;
+			my ( $word ) = $_ =~ /(\w{2,})/xms;
+
+			next unless $word;
 
 			$self->log_debug( 'copyright_holder word: ' . $word );
 
@@ -114,7 +116,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.002001
+version 2.002002
 
 =head1 SYNOPSIS
 
@@ -214,22 +216,16 @@ This is free software, licensed under:
 
 __DATA__
 ___[ xt/author/pod-spell.t ]___
-#!perl
-
 # This test is generated by Dist::Zilla::Plugin::Test::PodSpelling
-
+use strict;
+use warnings;
 use Test::More;
-
-eval "use {{ $wordlist }}";
-plan skip_all => "{{ $wordlist }} required for testing POD spelling"
-  if $@;
-
-eval "use Test::Spelling 0.12";
-plan skip_all => "Test::Spelling 0.12 required for testing POD spelling"
-  if $@;
+use Test::Requires {
+    'Test::Spelling'  => 0.12,
+    '{{ $wordlist }}' => 0,
+};
 
 {{ $set_spell_cmd }}
 {{ $add_stopwords }}
 all_pod_files_spelling_ok('bin', 'lib');
 {{ $stopwords }}
-
